#!/usr/bin/env ruby
# Simple script to start a Catapult instance, which you can shut down either
# through a browser or the command line with Ctrl-C.  Catpult dynamically
# loads classes to execute code via WEBrick.   It looks in the standard Ruby
# path, as well as in any directories specified in the CATAPULT_PATH
# environment variable.
#
# You can add directories to that path by lisintg the dirctories at the end of
# this file, past the _ _ END _ _ section
#  
# See the docs for Catapult to see what parameters you may pass to a new
# Catapult instance.


$:.push( File.expand_path( File.dirname( __FILE__) ) ) 

require 'catapult'
require 'open-uri'
require 'logger'

include Neurogami

$catalog = Logger.new( "log__lanunch.rb.log"  )
$catalog.level = Logger::DEBUG

  # Delimeter used to seperate file paths in +ENV['PATH']+
def delim
  /mswin/ =~ RUBY_PLATFORM ?  ';' :   ':'   
end

def expand_paths( dirs )
  currdir = File.expand_path( File.dirname( __FILE__) )
  dirs.split( $/ ).map{ |line|
    File.expand_path( File.join( currdir , line).strip )
  }.join( $/ )
end


  # See if we have anything after the _ _ END _ _ demarcation, and
  # add what we find to the CATAPULT_PATH environemt variable so
  # Catapult knows where to look when loading code
def add_paths
  dirs = DATA.read
  if dirs.to_s.strip.size > 0
    dirs = expand_paths( dirs.to_s.strip ).strip.gsub( "\n", delim )
    $catalog.debug( "Have dirs: #{dirs}") 
    ENV[ 'CATAPULT_PATH' ] = '.' unless ENV[ 'CATAPULT_PATH' ] 
    ENV[ 'CATAPULT_PATH' ] = ENV[ 'CATAPULT_PATH' ] +  delim if ENV[ 'CATAPULT_PATH' ].to_s.size > 0
    ENV[ 'CATAPULT_PATH' ] = ENV[ 'CATAPULT_PATH' ] +  delim + dirs
  end
end

PORT=8090


  begin
    $catalog.debug( "Start of main section for #{__FILE__}" )
    add_paths
    $catalog.debug( "Paths have been added" )    
    trap( 1 ) { 
      $catalog.info( "Trapped 1" )      
      URI.parse( "http://localhost:#{PORT}/quit" ).read 
    }
    trap( "SIGINT" ) { 
      $catalog.info(  "Trapped SIGINT" )
      URI.parse( "http://localhost:#{PORT}/quit" ).read 
    }  
    $catalog.debug( "Run a new instance of Catapult on port  #{PORT}" )    
    Catapult.new( :port=>PORT ).run()
  rescue Exception
    STDERR.puts( "Error! #{$!}")
    $catalog.error(  "Error! #{$!}")
    URI.parse( "http://localhost:#{PORT}/quit" ).read
  end

  

$catalog.debug(  "All done, at #{Time.new.to_s}" )  

__END__
..\examples

